/*
 * Rediger denne fila og kopier henne som userChrome.css til
 * di profilmappe/chrome/
 */

/*
 * Denne fila kan brukast til å endre utsjånaden på brukargrensesnittet 
 * til Mozilla. Om du vil overstyre standardinnstillingane kan
 * du bruke !important.
 */

/*
 * Ikkje fjern @namespace-linja, ho må vere tilstades for at ting skal fungere.
 */
@namespace url("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul"); /* set default namespace to XUL */


/*
 * Nokre moglege reglar for å auke tilgjenget:
 */
/*
 * Gjer alle skriftstorleikar om til 20 punkt
 *
 * * {
 *   font-size: 20pt !important
 * }
 */
/*
 * Gjer skriftstorleiken i alle menyar om til 15 punkt
 *
 * menupopup > * {
 *   font-size: 15pt !important
 * }
 */
/*
 * Gje adresselinja ei ikkje-proporsjonal skrift.
 *
 * #urlbar {
 *    font-family: monospace !important;
 * }
 */

/*
 * Fjern lastingsanimasjonen
 *
 * #throbber-box {
 *   display: none !important;
 * }
 */

/*
 * Du finn fleire døme (på engelsk) på http://www.mozilla.org/unix/customizing.html
 */
 
