//@line 35 "/builds/slave/linux_repack/build/releases/l10n-mozilla-1.9.1/nn-NO/browser/firefox-l10n.js"

//@line 37 "/builds/slave/linux_repack/build/releases/l10n-mozilla-1.9.1/nn-NO/browser/firefox-l10n.js"

pref("general.useragent.locale", "nn-NO");
pref("browser.fixup.alternate.suffix", ".no");
