/*
 * Rediger denne fila og kopier henne til userContent.css i di
 * profilmappe/chrome/
 */

/*
 * Denne fila kan brukast til å leggje på stilar til alle nettstader
 * du viser i Mozilla. Stilreglar utan !important kan overstyrast av
 * nettstadsansvarleg.
 */

/*
 * døme: skru av blinkinga til "blink"-elementet
 *
 * blink { text-decoration: none ! important; }
 *
 */

/*
 * døme: gje alle tabellar ei 2px synleg ramme
 *
 * table { border: 2px solid; }
 */

/*
 * døme: skrua av "marquee"-elementet
 *
 * marquee { -moz-binding: none; }
 *
 */
 
/*
 * Du finn fleire døme (på engelsk) på http://www.mozilla.org/unix/customizing.html
 */

